var module_profiler_8c =
[
    [ "impl", "structimpl.html", "structimpl" ],
    [ "resource_data", "structresource__data.html", "structresource__data" ],
    [ "DEFAULT_IDLE", "module-profiler_8c.html#aff355968598e44b9520aef427020ced6", null ],
    [ "DEFAULT_INTERVAL", "module-profiler_8c.html#a3721f0c1bea7a4a0b98d348a4a9f1cca", null ],
    [ "MAX_BUFFER", "module-profiler_8c.html#a1d5dab30b404fab91608086105afc78c", null ],
    [ "MIN_FLUSH", "module-profiler_8c.html#a40a66fc92b64ca0c396750a7b7bc3a8e", null ],
    [ "NAME", "module-profiler_8c.html#a47f2e62c0dbebc787052c165afcada0e", null ],
    [ "PW_LOG_TOPIC_DEFAULT", "module-profiler_8c.html#a37f02197895628b68a81bc1ef06d0f65", null ],
    [ "pw_profiler_resource", "module-profiler_8c.html#a709ddbce3df2e4c14ede2b061d609cef", null ],
    [ "pw_profiler_resource_profile", "module-profiler_8c.html#aef8d82be1817ced8befab53fb562f27e", null ],
    [ "TMP_BUFFER", "module-profiler_8c.html#a13cf8a1771cd7581abfa55c383ef5da5", null ],
    [ "pipewire__module_init", "module-profiler_8c.html#a8a1bb60befc3b89c8c1f5417f777083f", null ],
    [ "PW_LOG_TOPIC", "module-profiler_8c.html#a25d870f60f991a83eae379650774a19c", null ],
    [ "pw_protocol_native_ext_profiler_init", "module-profiler_8c.html#a2343e81fc9879b56eb53cd3c242b754a", null ]
];